@@ -1,8 +1,8 @@
 import base64
-import ecdsa
-import time
 import logging
+import time
 
+import ecdsa
 import jwt
 from ecdsa import SigningKey, VerifyingKey
 from pydantic import BaseModel, EmailStr
@@ -17,23 +17,6 @@ class JwtParam(BaseModel):
     domain: str
 
 
-def get_signing_key(secret_binary: bytes) -> SigningKey:
-    try:
-        signing_key_der = base64.b64decode(secret_binary)
-        return ecdsa.SigningKey.generate().from_der(signing_key_der)
-    except Exception as ex:
-        LOG.error(f"{ex}")
-        return None
-
-
-def get_verifying_key(secret_binary: bytes) -> VerifyingKey:
-    try:
-        return get_signing_key(secret_binary).get_verifying_key()
-    except Exception as ex:
-        LOG.error(f"{ex}")
-        return None
-
-
 def create_jwt(
     jwt_param: JwtParam,
     signing_key: SigningKey,
@@ -63,7 +46,7 @@ def create_jwt(
 
 def create_empty_jwt(
     signing_key: SigningKey, audience: str, issuer: str, algorithm=DEFAULT_ALGORITHM
-):
+) -> str:
 
     now = int(time.time())
     return jwt.encode(
@@ -86,7 +69,7 @@ def decode_jwt(
     algorithm=DEFAULT_ALGORITHM,
 ):
     return jwt.decode(
-        jwt_string.encode("utf-8"),
+        jwt_string,
         verifying_key.to_pem(),
         algorithms=[algorithm],
         audience=audience,
